==> haskell-io-streams-haproxy-1.0.0.2-24-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-io-streams-haproxy.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: io-streams-haproxy
version: 1.0.0.2
id: io-streams-haproxy-1.0.0.2-7768sS8XvoKqM7hY9ZYEV
key: io-streams-haproxy-1.0.0.2-7768sS8XvoKqM7hY9ZYEV
license: BSD-3-Clause
copyright: (c) 2014 Google, Inc. and CONTRIBUTORS
maintainer: greg@gregorycollins.net
author: Gregory Collins
homepage: http://snapframework.com/
synopsis: HAProxy protocol 1.5 support for io-streams
description:
    HAProxy protocol version 1.5 support (see
    <http://haproxy.1wt.eu/download/1.5/doc/proxy-protocol.txt>) for applications
    using io-streams. The proxy protocol allows information about a networked
    peer (like remote address and port) to be propagated through a forwarding
    proxy that is configured to speak this protocol.
category: Network, IO-Streams
abi: c5fd224bae044fc0597e980e7d5dadbe
exposed: True
exposed-modules:
    System.IO.Streams.Network.HAProxy
hidden-modules: System.IO.Streams.Network.Internal.Address
import-dirs: /usr/lib/ghc-8.4.3/site-local/io-streams-haproxy-1.0.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/io-streams-haproxy-1.0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/io-streams-haproxy-1.0.0.2
hs-libraries: HSio-streams-haproxy-1.0.0.2-7768sS8XvoKqM7hY9ZYEV
depends:
    base-4.11.1.0 attoparsec-0.13.2.2-5oKqcFqqk8HLoRElqn64fK
    bytestring-0.10.8.2 io-streams-1.5.0.1-2bVNxAA2r1O57zSFpx0loj
    network-2.7.0.2-8yE8vwBlEy1KZPVD4sTAn transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             attoparsec-0.13.2.2-5oKqcFqqk8HLoRElqn64fK=fff7ae21f45c1b0af12007963cebbf81
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             io-streams-1.5.0.1-2bVNxAA2r1O57zSFpx0loj=c29d11fe530951aff4dc7b9acd92aa68
             network-2.7.0.2-8yE8vwBlEy1KZPVD4sTAn=90fa8650caae170586ac66be24e6a39f
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-io-streams-haproxy/html/io-streams-haproxy.haddock
haddock-html: /usr/share/doc/haskell-io-streams-haproxy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-io-streams-haproxy-1.0.0.2-25-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-io-streams-haproxy.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: io-streams-haproxy
version: 1.0.0.2
id: io-streams-haproxy-1.0.0.2-4IG5Rn1ilk8CASYhYvfD6O
key: io-streams-haproxy-1.0.0.2-4IG5Rn1ilk8CASYhYvfD6O
license: BSD-3-Clause
copyright: (c) 2014 Google, Inc. and CONTRIBUTORS
maintainer: greg@gregorycollins.net
author: Gregory Collins
homepage: http://snapframework.com/
synopsis: HAProxy protocol 1.5 support for io-streams
description:
    HAProxy protocol version 1.5 support (see
    <http://haproxy.1wt.eu/download/1.5/doc/proxy-protocol.txt>) for applications
    using io-streams. The proxy protocol allows information about a networked
    peer (like remote address and port) to be propagated through a forwarding
    proxy that is configured to speak this protocol.
category: Network, IO-Streams
abi: f97e5dd1f751cb4e8701560a447a715b
exposed: True
exposed-modules:
    System.IO.Streams.Network.HAProxy
hidden-modules: System.IO.Streams.Network.Internal.Address
import-dirs: /usr/lib/ghc-8.4.3/site-local/io-streams-haproxy-1.0.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/io-streams-haproxy-1.0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/io-streams-haproxy-1.0.0.2
hs-libraries: HSio-streams-haproxy-1.0.0.2-4IG5Rn1ilk8CASYhYvfD6O
depends:
    base-4.11.1.0 attoparsec-0.13.2.2-LRi8ukEwwi1GyId6oqTEFJ
    bytestring-0.10.8.2 io-streams-1.5.0.1-IQSRKdqvO3e5ntUOI8deUZ
    network-2.7.0.2-8yE8vwBlEy1KZPVD4sTAn transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             attoparsec-0.13.2.2-LRi8ukEwwi1GyId6oqTEFJ=b8f8a17746566009aae6e9799affc625
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             io-streams-1.5.0.1-IQSRKdqvO3e5ntUOI8deUZ=8d48093b7ba3c027f28894a69172c076
             network-2.7.0.2-8yE8vwBlEy1KZPVD4sTAn=90fa8650caae170586ac66be24e6a39f
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-io-streams-haproxy/html/io-streams-haproxy.haddock
haddock-html: /usr/share/doc/haskell-io-streams-haproxy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
